@@ -30,7 +30,7 @@ y = openapi.Parameter(
 palette = openapi.Parameter(
     'palette',
     openapi.IN_QUERY,
-    description='The color palette to map the band values (named Matplotlib colormaps or palettable palettes).',
+    description='The color palette to map the band values (named Matplotlib colormaps or palettable palettes). `cmap` alias supported.',
     type=openapi.TYPE_STRING,
 )
 band = openapi.Parameter(
@@ -66,7 +66,7 @@ scheme = openapi.Parameter(
 style = openapi.Parameter(
     'style',
     openapi.IN_QUERY,
-    description='Base64 encoded JSON style following https://girder.github.io/large_image/tilesource_options.html#style',
+    description='Encoded string of JSON style following https://girder.github.io/large_image/tilesource_options.html#style . This can optionally be Base64 encoded if too large for URL.',
     type=openapi.TYPE_STRING,
 )
 
